Change Log
==========
All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/>`_
and this project adheres to `Semantic Versioning <http://semver.org/>`_

0.2.0 - 2017-10-23
------------------
This is the October 2017 Beta 1 release, containing the following features:

- Summaries of the statistics, compilation, and biological grammar of newtworks
- Query building including seeding by nodes, authors, and citations
- Biological network explorer with annotation browser
